@@ -8,10 +8,16 @@ from django.urls import re_path
 from core_curate_app.views.common import views as common_views
 
 admin_urls = [
-    re_path(r'^view-form/(?P<curate_data_structure_id>\w+)$', staff_member_required(common_views.FormView.as_view(
-        administration=True,
-        template='core_curate_app/admin/view_curate_data_structure.html')),
-        name='core_curate_view_form')
+    re_path(
+        r"^view-form/(?P<curate_data_structure_id>\w+)$",
+        staff_member_required(
+            common_views.FormView.as_view(
+                administration=True,
+                template="core_curate_app/admin/view_curate_data_structure.html",
+            )
+        ),
+        name="core_curate_view_form",
+    )
 ]
 
 
